clear all; close all; clc;

%load sensor.hys
Ts=0.5;
bMAX=80;
rOUTmax=100;
rINmax=120;
btLOW=10;
pMAX=90;

clc

% Generate the MLD model
S=mld('sensormodel_full',Ts);

% Generate the equivalent PWA model
P=pwa(S);


 % Design MPC controller
clear Q refs limits

refs.x=1;   % only state x(2) is weighted
Q.x=1;      % weight on state x(2)
Q.rho=Inf;  % hard constraints
%Q.norm=2;   % use quadratic costs
Q.norm=Inf; % use infinity norm
N=2;

limits.xmin=[0;0;0;0];

C=hybcon(S,Q,N,limits,refs);
C.mipsolver='glpk';   % used for MILP
%C.mipsolver='cplex';  % used for MIQP
Tstop=100;
x0=[0;0;40;0]; % initial state
clear r
TS=[0:Ts:99.5]';
U=zeros(length(TS),1)
for i=1:length(TS)

    U(i)=85*(TS(i)>=0)*(TS(i)<=20);
end
r.x=U;


% Simulate Hybrid MPC loop using from command line
[XX,UU,DD,ZZ,TT]=sim(C,S,r,x0,Tstop);
figure
subplot(311);
plot(TT,2*XX(:,2),TT,UU);
axis([0 30 0 130]);
grid
title('CPU (%), Rin(MB/s)')
subplot(312);
plot(TT,XX(:,1),TT,r.x);
axis([0 30 0 100]);
grid
title('Buffer (MB)')
subplot(313);
plot(TT,XX(:,3));
axis([0 30 0 50]);
grid
title('Battery (%)')
set(gcf,'position',[360    55   385   623]);